@@ -30,7 +30,7 @@ from . import helpers
 from . import objects
 from .settings import CONFIG
 
-__version__ = '1.0'
+__version__ = '1.0.1'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -119,6 +119,8 @@ class Config(object):  # pylint: disable-msg=R0903
         self.default_content_limit = int(obj['default_content_limit'])
         self.domain = obj['domain']
         self.more_comments_max = int(obj['more_comments_max'])
+        self.log_requests = int(obj['log_requests'])
+
         if 'short_domain' in obj:
             self._short_domain = 'http://' + obj['short_domain']
         else:
