@@ -825,11 +825,20 @@ class SubredditTest(unittest.TestCase, AuthenticatedHelper):
         mod_submissions = list(self.r.get_subreddit('mod').get_modqueue())
         self.assertTrue(len(mod_submissions) > 0)
 
+    def test_get_modqueue_multi(self):
+        multi = '{0}+{1}'.format(self.sr, 'reddit_api_test2')
+        mod_submissions = list(self.r.get_subreddit(multi).get_modqueue())
+        self.assertTrue(len(mod_submissions) > 0)
+
     def test_moderator_requried(self):
         oth = Reddit(USER_AGENT)
         oth.login('PyApiTestUser3', '1111')
         self.assertRaises(errors.ModeratorRequired, oth.get_settings, self.sr)
 
+    def test_moderator_requried_multi(self):
+        sub = self.r.get_subreddit('{0}+{1}'.format(self.sr, 'test'))
+        self.assertRaises(errors.ModeratorRequired, sub.get_modqueue)
+
     def test_my_reddits(self):
         for subreddit in self.r.user.my_reddits():
             # pylint: disable-msg=W0212
